pub struct ChanAcl {
pub apply_here: Option<bool>,
pub apply_subs: Option<bool>,
pub inherited: Option<bool>,
pub user_id: Option<u32>,
pub group: Option<String>,
pub grant: Option<u32>,
pub deny: Option<u32>,
}Fields
apply_here: Option<bool>True if this ACL applies to the current channel.
apply_subs: Option<bool>True if this ACL applies to the sub channels.
inherited: Option<bool>True if the ACL has been inherited from the parent.
user_id: Option<u32>ID of the user that is affected by this ACL.
group: Option<String>ID of the group that is affected by this ACL.
grant: Option<u32>Bit flag field of the permissions granted by this ACL.
deny: Option<u32>Bit flag field of the permissions denied by this ACL.
Implementations
Sourceimpl ChanAcl
impl ChanAcl
Sourcepub fn apply_here(&self) -> bool
pub fn apply_here(&self) -> bool
Returns the value of apply_here, or the default value if apply_here is unset.
Sourcepub fn apply_subs(&self) -> bool
pub fn apply_subs(&self) -> bool
Returns the value of apply_subs, or the default value if apply_subs is unset.
Sourcepub fn inherited(&self) -> bool
pub fn inherited(&self) -> bool
Returns the value of inherited, or the default value if inherited is unset.
Sourcepub fn user_id(&self) -> u32
pub fn user_id(&self) -> u32
Returns the value of user_id, or the default value if user_id is unset.