#[repr(i32)]pub enum Context {
Server = 1,
Channel = 2,
User = 4,
}Variants
Server = 1
Action is applicable to the server.
Channel = 2
Action can target a Channel.
User = 4
Action can target a User.
Implementations
Sourceimpl Context
impl Context
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.