pub struct CodecVersion {
pub alpha: i32,
pub beta: i32,
pub prefer_alpha: bool,
pub opus: Option<bool>,
}Expand description
Sent by the server to notify the users of the version of the CELT codec they should use. This may change during the connection when new users join.
Fields
alpha: i32The version of the CELT Alpha codec.
beta: i32The version of the CELT Beta codec.
prefer_alpha: boolTrue if the user should prefer Alpha over Beta.
opus: Option<bool>Implementations