pub struct ContextAction {
pub session: Option<u32>,
pub channel_id: Option<u32>,
pub action: String,
}Expand description
Sent by the client when it wants to initiate a Context action.
Fields
session: Option<u32>The target User for the action, identified by session.
channel_id: Option<u32>The target Channel for the action, identified by channel_id.
action: StringThe action that should be executed.
Implementations
Sourceimpl ContextAction
impl ContextAction