pub struct PermissionDenied {
pub permission: Option<u32>,
pub channel_id: Option<u32>,
pub session: Option<u32>,
pub reason: Option<String>,
pub type: Option<i32>,
pub name: Option<String>,
}Fields
permission: Option<u32>The denied permission when type is Permission.
channel_id: Option<u32>channel_id for the channel where the permission was denied when type is Permission.
session: Option<u32>The user who was denied permissions, identified by session.
reason: Option<String>Textual reason for the denial.
type: Option<i32>Type of the denial.
name: Option<String>The name that is invalid when type is UserName.
Implementations
Sourceimpl PermissionDenied
impl PermissionDenied
Sourcepub fn permission(&self) -> u32
pub fn permission(&self) -> u32
Returns the value of permission, or the default value if permission is unset.
Sourcepub fn channel_id(&self) -> u32
pub fn channel_id(&self) -> u32
Returns the value of channel_id, or the default value if channel_id is unset.
Sourcepub fn session(&self) -> u32
pub fn session(&self) -> u32
Returns the value of session, or the default value if session is unset.
Sourcepub fn reason(&self) -> &str
pub fn reason(&self) -> &str
Returns the value of reason, or the default value if reason is unset.