PluginDataTransmission

Struct PluginDataTransmission 

pub struct PluginDataTransmission {
    pub sender_session: Option<u32>,
    pub receiver_sessions: Vec<u32>,
    pub data: Option<Vec<u8>>,
    pub data_id: Option<String>,
}
Used to send plugin messages between clients

Fields

sender_session: Option<u32>

The session ID of the client this message was sent from

receiver_sessions: Vec<u32>

The session IDs of the clients that should receive this message

data: Option<Vec<u8>>

The data that is sent

data_id: Option<String>

The ID of the sent data. This will be used by plugins to check whether they will process it or not

Implementations

Source

impl PluginDataTransmission

pub fn sender_session(&self) -> u32

Returns the value of sender_session, or the default value if sender_session is unset.

pub fn data(&self) -> &[u8]

Returns the value of data, or the default value if data is unset.

pub fn data_id(&self) -> &str

Returns the value of data_id, or the default value if data_id is unset.