Ping

Struct Ping 

pub struct Ping {
    pub timestamp: u64,
    pub request_extended_information: bool,
    pub server_version_v2: u64,
    pub user_count: u32,
    pub max_user_count: u32,
    pub max_bandwidth_per_user: u32,
}
Ping message for checking UDP connectivity (and roundtrip ping) and potentially obtaining further server details (e.g. version).

Fields

timestamp: u64

Timestamp as encoded by the client. A server is not supposed to attempt to decode or modify this field. Therefore, clients may choose an arbitrary format for this timestamp (as long as it fits into a uint64 field).

request_extended_information: bool

A flag set by the sending client, if it wants to obtain additional information about the server.

server_version_v2: u64

The version of the server in the new version format. The new protobuf Ping packet introduced with 1.5 drops support for the legacy version format since both server and client have to support this new format. (See https://github.com/mumble-voip/mumble/issues/5827)

user_count: u32

The amount of users currently connected to the server

max_user_count: u32

The maximum amount of users permitted on this server

max_bandwidth_per_user: u32

The maximum bandwidth each user is allowed to use for sending audio to the server