pub struct ChanGroup {
pub name: String,
pub inherited: Option<bool>,
pub inherit: Option<bool>,
pub inheritable: Option<bool>,
pub add: Vec<u32>,
pub remove: Vec<u32>,
pub inherited_members: Vec<u32>,
}Fields
name: StringName of the channel group, UTF-8 encoded.
inherited: Option<bool>True if the group has been inherited from the parent (Read only).
inherit: Option<bool>True if the group members are inherited.
inheritable: Option<bool>True if the group can be inherited by sub channels.
add: Vec<u32>Users explicitly included in this group, identified by user_id.
remove: Vec<u32>Users explicitly removed from this group in this channel if the group has been inherited, identified by user_id.
inherited_members: Vec<u32>Users inherited, identified by user_id.
Implementations
Sourceimpl ChanGroup
impl ChanGroup
Sourcepub fn inherited(&self) -> bool
pub fn inherited(&self) -> bool
Returns the value of inherited, or the default value if inherited is unset.
Sourcepub fn inherit(&self) -> bool
pub fn inherit(&self) -> bool
Returns the value of inherit, or the default value if inherit is unset.
Sourcepub fn inheritable(&self) -> bool
pub fn inheritable(&self) -> bool
Returns the value of inheritable, or the default value if inheritable is unset.