pub struct BanList {
pub bans: Vec<BanEntry>,
pub query: Option<bool>,
}Expand description
Relays information on the bans. The client may send the BanList message to either modify the list of bans or query them from the server. The server sends this list only after a client queries for it.
Fields
bans: Vec<BanEntry>List of ban entries currently in place.
query: Option<bool>True if the server should return the list, false if it should replace old ban list with the one provided.
Implementations