pub struct PluginDataTransmission {
pub sender_session: Option<u32>,
pub receiver_sessions: Vec<u32>,
pub data: Option<Vec<u8>>,
pub data_id: Option<String>,
}Expand description
Used to send plugin messages between clients
Fields
sender_session: Option<u32>The session ID of the client this message was sent from
receiver_sessions: Vec<u32>The session IDs of the clients that should receive this message
data: Option<Vec<u8>>The data that is sent
data_id: Option<String>The ID of the sent data. This will be used by plugins to check whether they will process it or not
Implementations
Sourceimpl PluginDataTransmission
impl PluginDataTransmission