pub struct RequestBlob {
pub session_texture: Vec<u32>,
pub session_comment: Vec<u32>,
pub channel_description: Vec<u32>,
}Expand description
Used by the client to request binary data from the server. By default large comments or textures are not sent within standard messages but instead the hash is. If the client does not recognize the hash it may request the resource when it needs it. The client does so by sending a RequestBlob message with the correct fields filled with the user sessions or channel_ids it wants to receive. The server replies to this by sending a new UserState/ChannelState message with the resources filled even if they would normally be transmitted as hashes.
Fields
session_texture: Vec<u32>sessions of the requested UserState textures.
session_comment: Vec<u32>sessions of the requested UserState comments.
channel_description: Vec<u32>channel_ids of the requested ChannelState descriptions.