pub struct Target {
pub session: Vec<u32>,
pub channel_id: Option<u32>,
pub group: Option<String>,
pub links: Option<bool>,
pub children: Option<bool>,
}Fields
session: Vec<u32>Users that are included as targets.
channel_id: Option<u32>Channel that is included as a target.
group: Option<String>ACL group that is included as a target.
links: Option<bool>True if the voice should follow links from the specified channel.
children: Option<bool>True if the voice should also be sent to children of the specific channel.
Implementations
Sourceimpl Target
impl Target
Sourcepub fn channel_id(&self) -> u32
pub fn channel_id(&self) -> u32
Returns the value of channel_id, or the default value if channel_id is unset.
Sourcepub fn group(&self) -> &str
pub fn group(&self) -> &str
Returns the value of group, or the default value if group is unset.